import { HttpClient, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { R as Reservation, C as CreateReservationOptions, G as GetReservationOptions, U as UpdateReservation, a as UpdateReservationOptions, H as HeldReservationDetails, b as CreateHeldReservationResponse, c as Reservee, d as ReserveReservationResponse, e as CancelReservationOptions, f as CancelReservationResponse, L as ListReservationsOptions, g as ListReservationsResponse, h as ReservationsQueryBuilder, i as ReservationSearch, S as SearchReservationsResponse, B as BulkArchiveReservationsResponse, j as BulkUnArchiveReservationsResponse, k as ReservationCreatedEnvelope, l as ReservationDeletedEnvelope, m as ReservationUpdatedEnvelope } from './table-reservations-v1-reservation-reservations.universal-iVx94_Pd.js';
export { b4 as ActionEvent, al as Aggregation, ay as AggregationData, am as AggregationKindOneOf, aR as AggregationResults, aS as AggregationResultsResultOneOf, aF as AggregationResultsScalarResult, A as AggregationType, aW as ApplicationError, bg as BaseEventMetadata, aX as BulkActionMetadata, aT as BulkArchiveReservationsRequest, aU as BulkArchiveReservationsResult, aY as BulkUnArchiveReservationsRequest, aZ as BulkUnArchiveReservationsResult, a5 as CancelReservationRequest, a3 as CreateHeldReservationRequest, V as CreateReservationRequest, X as CreateReservationResponse, aa as CursorPaging, ac as CursorPagingMetadata, af as CursorQuery, ag as CursorQueryPagingMethodOneOf, aj as CursorSearch, ak as CursorSearchPagingMethodOneOf, ad as Cursors, at as DateHistogramAggregation, aN as DateHistogramResult, aP as DateHistogramResults, a7 as DeleteReservationRequest, a8 as DeleteReservationResponse, D as Details, a_ as DomainEvent, a$ as DomainEventBodyOneOf, b5 as Empty, b0 as EntityCreatedEvent, b3 as EntityDeletedEvent, b2 as EntityUpdatedEvent, bh as EventMetadata, E as ExtendedFields, $ as GetReservationRequest, a0 as GetReservationResponse, aO as GroupByValueResults, bb as HeadersEntry, be as IdentificationData, bf as IdentificationDataIdOneOf, ao as IncludeMissingValuesOptions, I as Interval, aV as ItemMetadata, a9 as ListReservationsRequest, bd as MessageEnvelope, y as MigrationNote, M as MissingValues, v as Mode, aw as NestedAggregation, au as NestedAggregationItem, av as NestedAggregationItemKindOneOf, aB as NestedAggregationResults, aC as NestedAggregationResultsResultOneOf, N as NestedAggregationType, aK as NestedResultValue, aL as NestedResultValueResultOneOf, aQ as NestedResults, aG as NestedValueAggregationResult, b9 as PathParametersEntry, P as PaymentStatus, ba as QueryParametersEntry, ae as QueryReservationsRequest, ah as QueryReservationsResponse, ar as RangeAggregation, aA as RangeAggregationResult, an as RangeBucket, aI as RangeResult, aE as RangeResults, b8 as RawHttpRequest, bc as RawHttpResponse, b6 as RemoveReservationMigrationNotesRequest, b7 as RemoveReservationMigrationNotesResponse, a6 as ReservationCanceled, K as ReservationCreated, F as ReservationDelayedDomainEvent, J as ReservationDelayedDomainEventBodyTypeOneOf, Q as ReservationDelayedDomainEventReservationCanceled, Y as ReservationDetailsConflicts, _ as ReservationLocationConflict, bj as ReservationSearchSpec, O as ReservationUpdated, bi as ReservationsQueryResult, a4 as ReserveReservationRequest, x as ReservedBy, b1 as RestoreInfo, aM as Results, as as ScalarAggregation, aJ as ScalarResult, u as ScalarType, ax as SearchDetails, ai as SearchReservationsRequest, q as Set, t as SortDirection, r as SortOrder, s as SortType, ab as Sorting, o as Source, n as Status, Z as TableCombinationConflict, T as TableCombinationConflictType, z as TableWithReservationConflicts, w as Tables, p as Type, a1 as UpdateReservationRequest, a2 as UpdateReservationResponse, ap as ValueAggregation, aq as ValueAggregationOptionsOneOf, az as ValueAggregationResult, aH as ValueResult, aD as ValueResults, W as WebhookIdentityType } from './table-reservations-v1-reservation-reservations.universal-iVx94_Pd.js';

declare function createReservation$1(httpClient: HttpClient): CreateReservationSignature;
interface CreateReservationSignature {
    /**
     * Creates a new reservation.
     *
     * `createReservation()` accepts and requires different fields depending on the `status` provided and your permissions.
     *
     * **Status and source**
     *
     * If a `status` is not provided, it will be set to:
     * * `RESERVED` if manual approval is not required for confirmation
     * * `REQUESTED` if manual approval is required for confirmation.
     *
     * A reservation created with any `source` other than `WALK_IN` requires the `reservation.reservee.phone` and `reservation.reservee.firstName` fields.
     * Attempting to create a reservation without these fields will result in an error.
     *
     * **Permissions**
     *
     * Including the fields `status`, `source`, `reservation.details.tableIds`, `reservation.details.endDate`, `ignoreReservationLocationConflicts`, or `ignoreTableCombinationConflicts` in the request requires additional permissions. See this API's Introduction article for more information.
     *
     * If `source` is not provided, its value is set depending on the permissions of the user making the call. See this API's Introduction article for more information.
     *
     *
     *  > **Note:** `createReservation()` requires all details of the reservation upfront. The process of creating a reservation can be broken up using `createHeldReservation`.  `createHeldReservation` creates a temporary reservation that expires automatically unless it is completed with the addition of more details using `reserveReservation()`.
     * @param - Reservation details.
     * @param - Options for creating the reservation.
     * @returns Reservation.
     */
    (reservation: Reservation, options?: CreateReservationOptions | undefined): Promise<Reservation>;
}
declare function getReservation$1(httpClient: HttpClient): GetReservationSignature;
interface GetReservationSignature {
    /**
     * Retrieves a reservation.
     *
     * Calling this method with `fieldsets` set to `FULL` requires additional permissions. See this API's Introduction article for more information.
     * @param - Reservation ID.
     * @returns Reservation.
     */
    (reservationId: string, options?: GetReservationOptions | undefined): Promise<Reservation>;
}
declare function updateReservation$1(httpClient: HttpClient): UpdateReservationSignature;
interface UpdateReservationSignature {
    /**
     * Updates a reservation.
     *
     * Including the fields `status`, `source`, `reservation.details.tableIds`, `reservation.details.endDate`, `ignoreReservationLocationConflicts`, and `ignoreTableCombinationConflicts` in the request requires additional permissions. See this API's Introduction article for more information.
     *
     * Each time the reservation is updated, revision increments by 1. The existing revision must be included when updating the reservation. This ensures you're working with the latest reservation information, and it prevents unintended overwrites.
     * @param - Reservation ID.
     * @param - Options for updating the reservation.
     * @param - Reservation information to update.
     * @returns Reservation.
     */
    (_id: string, reservation: UpdateReservation, options?: UpdateReservationOptions | undefined): Promise<Reservation>;
}
declare function createHeldReservation$1(httpClient: HttpClient): CreateHeldReservationSignature;
interface CreateHeldReservationSignature {
    /**
     * Creates a new temporary reservation and holds it for the customer for 10 minutes.
     *
     * Creates a new reservation with the `HELD` status. `HELD` reservations are intended to reserve seats and tables for a party in a selected time slot while they enter further reservation details, such as names and contact information. Reservations with the `HELD` status are only valid for 10 minutes. Trying to change a `HELD` reservation’s status after 10 minutes returns an error.
     *
     * You cannot call `updateReservation()` to change a reservation’s status from `HELD`. Trying to do so returns an error. Instead, you should use `reserveReservation()`.
     *
     * If you do not wish to have `HELD` reservations in your flow, you can create a reservation with all required details using `createReservation()`.
     *
     * @param - Held reservation information to update.
     */
    (reservationDetails: HeldReservationDetails): Promise<CreateHeldReservationResponse>;
}
declare function reserveReservation$1(httpClient: HttpClient): ReserveReservationSignature;
interface ReserveReservationSignature {
    /**
     * Reserves or requests a held reservation.
     *
     * Held reservations are temporary reservations with the `HELD` status created by `createHeldReservation()`.
     *
     * They are intended to reserve seats and tables for a party in a selected time slot while they enter further reservation details, such as names and contact information. Reservations with the `HELD` status are only valid for 10 minutes. Trying to call `Reserve Reservation` with a held reservation older than 10 minutes returns an error.
     *
     * `Reserve Reservation` changes a reservation's `HELD` status to:
     * * `RESERVED` if the reservation's reservation location does not require manual approval.
     * * `REQUESTED` if the reservation's reservation location requires manual approval.
     * @param - Reservation ID.
     * @param - Reservee details.
     * @param - Revision number.
     *
     * Specify the existing `revision` to prevent conflicting updates to reservations.
     */
    (reservationId: string, reservee: Reservee, revision: string): Promise<ReserveReservationResponse>;
}
declare function cancelReservation$1(httpClient: HttpClient): CancelReservationSignature;
interface CancelReservationSignature {
    /**
     * Cancels a reservation.
     *
     * Sets the reservation status to `CANCELED`.
     * @param - Reservation ID.
     * @param - Revision number.
     *
     * Specify the existing `revision` to prevent conflicting updates to reservations.
     * @param - Options for canceling the reservation.
     */
    (reservationId: string, revision: string, options?: CancelReservationOptions | undefined): Promise<CancelReservationResponse>;
}
declare function deleteReservation$1(httpClient: HttpClient): DeleteReservationSignature;
interface DeleteReservationSignature {
    /**
     * Deletes a reservation. Only reservations with the `HELD` status can be deleted.
     * @param - Reservation ID.
     */
    (reservationId: string): Promise<void>;
}
declare function listReservations$1(httpClient: HttpClient): ListReservationsSignature;
interface ListReservationsSignature {
    /**
     * Retrieves a list of up to 100 reservations.
     * @param - Options for listing the reservations.
     */
    (options?: ListReservationsOptions | undefined): Promise<ListReservationsResponse>;
}
declare function queryReservations$1(httpClient: HttpClient): QueryReservationsSignature;
interface QueryReservationsSignature {
    /**
     * Creates a query to retrieve a list of reservations.
     *
     * The `queryReservations()` function builds a query to retrieve a list of reservations and returns a `ReservationsQueryBuilder` object.
     *
     * The returned object contains the query definition, which is used to run the query using the [find()](/reservations/reservations-query-builder/find) function.
     *
     * You can refine the query by chaining `ReservationsQueryBuilder` functions onto the query. `ReservationsQueryBuilder` functions enable you to filter, sort, and control the results that `queryReservations()` returns.
     *
     * `queryReservations()` runs with the following `ReservationsQueryBuilder` defaults, which you can override:
     *
     * * [`limit(50)`](/reservations/reservations-query-builder/limit)
     * * [`descending('_createdDate')`](/reservations/reservations-query-builder/descending)
     *
     * The following `ReservationsQueryBuilder` functions are supported for `queryReservations()`. For a full description of the reservation object, see the object returned for the [`items`](/reservations/reservations-query-result/items) property in [`ReservationsQueryResult`](/reservations/reservations-query-result).
     */
    (): ReservationsQueryBuilder;
}
declare function searchReservations$1(httpClient: HttpClient): SearchReservationsSignature;
interface SearchReservationsSignature {
    /**
     * Use this method to search the fields of the table reservations on a site for a given expression.
     *
     * You can also use this method to perform data aggregations on a site's table reservation fields.
     * For a detailed list of supported operations, see the [Sorting, Filtering, and Search](https://dev.wix.com/docs/rest/api-reference/wix-restaurants/reservations/reservations/sorting-filtering-and-search) article.
     * @param - Search query.
     */
    (search: ReservationSearch): Promise<SearchReservationsResponse>;
}
declare function bulkArchiveReservations$1(httpClient: HttpClient): BulkArchiveReservationsSignature;
interface BulkArchiveReservationsSignature {
    /**
     * Bulk archive reservations.
     * @param - Reservation IDs to archive.
     */
    (reservationIds: string[]): Promise<BulkArchiveReservationsResponse>;
}
declare function bulkUnArchiveReservations$1(httpClient: HttpClient): BulkUnArchiveReservationsSignature;
interface BulkUnArchiveReservationsSignature {
    /**
     * Bulk unarchive reservations.
     * @param - Reservation IDs to unarchive.
     */
    (reservationIds: string[]): Promise<BulkUnArchiveReservationsResponse>;
}
declare const onReservationCreated$1: EventDefinition<ReservationCreatedEnvelope, "wix.table_reservations.v1.reservation_created">;
declare const onReservationDeleted$1: EventDefinition<ReservationDeletedEnvelope, "wix.table_reservations.v1.reservation_deleted">;
declare const onReservationUpdated$1: EventDefinition<ReservationUpdatedEnvelope, "wix.table_reservations.v1.reservation_updated">;

declare const createReservation: MaybeContext<BuildRESTFunction<typeof createReservation$1> & typeof createReservation$1>;
declare const getReservation: MaybeContext<BuildRESTFunction<typeof getReservation$1> & typeof getReservation$1>;
declare const updateReservation: MaybeContext<BuildRESTFunction<typeof updateReservation$1> & typeof updateReservation$1>;
declare const createHeldReservation: MaybeContext<BuildRESTFunction<typeof createHeldReservation$1> & typeof createHeldReservation$1>;
declare const reserveReservation: MaybeContext<BuildRESTFunction<typeof reserveReservation$1> & typeof reserveReservation$1>;
declare const cancelReservation: MaybeContext<BuildRESTFunction<typeof cancelReservation$1> & typeof cancelReservation$1>;
declare const deleteReservation: MaybeContext<BuildRESTFunction<typeof deleteReservation$1> & typeof deleteReservation$1>;
declare const listReservations: MaybeContext<BuildRESTFunction<typeof listReservations$1> & typeof listReservations$1>;
declare const queryReservations: MaybeContext<BuildRESTFunction<typeof queryReservations$1> & typeof queryReservations$1>;
declare const searchReservations: MaybeContext<BuildRESTFunction<typeof searchReservations$1> & typeof searchReservations$1>;
declare const bulkArchiveReservations: MaybeContext<BuildRESTFunction<typeof bulkArchiveReservations$1> & typeof bulkArchiveReservations$1>;
declare const bulkUnArchiveReservations: MaybeContext<BuildRESTFunction<typeof bulkUnArchiveReservations$1> & typeof bulkUnArchiveReservations$1>;
/**
 * Triggered when a held reservation is created.
 */
declare const onReservationCreated: BuildEventDefinition<typeof onReservationCreated$1>;
/**
 * Triggered when a reservation is deleted.
 */
declare const onReservationDeleted: BuildEventDefinition<typeof onReservationDeleted$1>;
/**
 * Triggered when a reservation is canceled.
 */
declare const onReservationUpdated: BuildEventDefinition<typeof onReservationUpdated$1>;

export { BulkArchiveReservationsResponse, BulkUnArchiveReservationsResponse, CancelReservationOptions, CancelReservationResponse, CreateHeldReservationResponse, CreateReservationOptions, GetReservationOptions, HeldReservationDetails, ListReservationsOptions, ListReservationsResponse, Reservation, ReservationCreatedEnvelope, ReservationDeletedEnvelope, ReservationUpdatedEnvelope, ReservationsQueryBuilder, ReserveReservationResponse, Reservee, SearchReservationsResponse, UpdateReservation, UpdateReservationOptions, bulkArchiveReservations, bulkUnArchiveReservations, cancelReservation, createHeldReservation, createReservation, deleteReservation, getReservation, listReservations, onReservationCreated, onReservationDeleted, onReservationUpdated, queryReservations, reserveReservation, searchReservations, updateReservation };
