// src/table-reservations-v1-reservation-reservations.public.ts
import { renameKeysFromRESTResponseToSDKResponse as renameKeysFromRESTResponseToSDKResponse2 } from "@wix/sdk-runtime/rename-all-nested-keys";
import { transformRESTTimestampToSDKTimestamp as transformRESTTimestampToSDKTimestamp2 } from "@wix/sdk-runtime/transformations/timestamp";
import { transformPaths as transformPaths3 } from "@wix/sdk-runtime/transformations/transform-paths";
import { EventDefinition } from "@wix/sdk-types";

// src/table-reservations-v1-reservation-reservations.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import { queryBuilder } from "@wix/sdk-runtime/query-builder";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/table-reservations-v1-reservation-reservations.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformSDKFloatToRESTFloat } from "@wix/sdk-runtime/transformations/float";
import { transformRESTFloatToSDKFloat } from "@wix/sdk-runtime/transformations/float";
import { transformSDKTimestampToRESTTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformSDKFieldMaskToRESTFieldMask } from "@wix/sdk-runtime/transformations/field-mask";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveWixTableReservationsReservationV1ReservationsServiceUrl(opts) {
  const domainToMappings = {
    _: [
      {
        srcPath: "/_api/table-reservations/reservations",
        destPath: ""
      }
    ],
    "editor.wixapps.net": [
      {
        srcPath: "/_api/table-reservations/reservations",
        destPath: ""
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/table-reservations/reservations",
        destPath: ""
      }
    ],
    "www._base_domain_": [
      {
        srcPath: "/_api/table-reservations/reservations",
        destPath: ""
      }
    ],
    "api._api_base_domain_": [
      {
        srcPath: "/table-reservations/reservations",
        destPath: ""
      }
    ],
    "*.dev.wix-code.com": [
      {
        srcPath: "/_api/table-reservations/reservations",
        destPath: ""
      }
    ],
    "editor._base_domain_": [
      {
        srcPath: "/_api/table-reservations/reservations",
        destPath: ""
      }
    ],
    "blocks._base_domain_": [
      {
        srcPath: "/_api/table-reservations/reservations",
        destPath: ""
      }
    ],
    "create.editorx": [
      {
        srcPath: "/_api/table-reservations/reservations",
        destPath: ""
      }
    ],
    "bo._base_domain_": [
      {
        srcPath: "/_api/table-reservations/reservations",
        destPath: ""
      }
    ],
    "wixbo.ai": [
      {
        srcPath: "/_api/table-reservations/reservations",
        destPath: ""
      }
    ],
    "wix-bo.com": [
      {
        srcPath: "/_api/table-reservations/reservations",
        destPath: ""
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/table-reservations/reservations",
        destPath: ""
      }
    ],
    "apps._base_domain_": [
      {
        srcPath: "/_api/table-reservations/reservations",
        destPath: ""
      }
    ],
    "dev._base_domain_": [
      {
        srcPath: "/_api/table-reservations/reservations",
        destPath: ""
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_table-reservations_reservations";
function createReservation(payload) {
  function __createReservation({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "reservation.createdDate" },
          { path: "reservation.updatedDate" },
          { path: "reservation.details.startDate" },
          { path: "reservation.details.endDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.table_reservations.v1.reservation",
      method: "POST",
      methodFqn: "wix.table_reservations.reservation.v1.ReservationsService.CreateReservation",
      packageName: PACKAGE_NAME,
      url: resolveWixTableReservationsReservationV1ReservationsServiceUrl({
        protoPath: "/v1/reservations",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "reservation.createdDate" },
            { path: "reservation.updatedDate" },
            { path: "reservation.details.startDate" },
            { path: "reservation.details.endDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __createReservation;
}
function getReservation(payload) {
  function __getReservation({ host }) {
    const metadata = {
      entityFqdn: "wix.table_reservations.v1.reservation",
      method: "GET",
      methodFqn: "wix.table_reservations.reservation.v1.ReservationsService.GetReservation",
      packageName: PACKAGE_NAME,
      url: resolveWixTableReservationsReservationV1ReservationsServiceUrl({
        protoPath: "/v1/reservations/{reservationId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "reservation.createdDate" },
            { path: "reservation.updatedDate" },
            { path: "reservation.details.startDate" },
            { path: "reservation.details.endDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getReservation;
}
function updateReservation(payload) {
  function __updateReservation({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFieldMaskToRESTFieldMask,
        paths: [{ path: "mask" }]
      },
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "reservation.createdDate" },
          { path: "reservation.updatedDate" },
          { path: "reservation.details.startDate" },
          { path: "reservation.details.endDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.table_reservations.v1.reservation",
      method: "PATCH",
      methodFqn: "wix.table_reservations.reservation.v1.ReservationsService.UpdateReservation",
      packageName: PACKAGE_NAME,
      url: resolveWixTableReservationsReservationV1ReservationsServiceUrl({
        protoPath: "/v1/reservations/{reservation.id}",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "reservation.createdDate" },
            { path: "reservation.updatedDate" },
            { path: "reservation.details.startDate" },
            { path: "reservation.details.endDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __updateReservation;
}
function createHeldReservation(payload) {
  function __createHeldReservation({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [{ path: "reservationDetails.startDate" }]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.table_reservations.v1.reservation",
      method: "POST",
      methodFqn: "wix.table_reservations.reservation.v1.ReservationsService.CreateHeldReservation",
      packageName: PACKAGE_NAME,
      url: resolveWixTableReservationsReservationV1ReservationsServiceUrl({
        protoPath: "/v1/reservations/hold",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "reservation.createdDate" },
            { path: "reservation.updatedDate" },
            { path: "reservation.details.startDate" },
            { path: "reservation.details.endDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __createHeldReservation;
}
function reserveReservation(payload) {
  function __reserveReservation({ host }) {
    const metadata = {
      entityFqdn: "wix.table_reservations.v1.reservation",
      method: "POST",
      methodFqn: "wix.table_reservations.reservation.v1.ReservationsService.ReserveReservation",
      packageName: PACKAGE_NAME,
      url: resolveWixTableReservationsReservationV1ReservationsServiceUrl({
        protoPath: "/v1/reservations/{reservationId}/reserve",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "reservation.createdDate" },
            { path: "reservation.updatedDate" },
            { path: "reservation.details.startDate" },
            { path: "reservation.details.endDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __reserveReservation;
}
function cancelReservation(payload) {
  function __cancelReservation({ host }) {
    const metadata = {
      entityFqdn: "wix.table_reservations.v1.reservation",
      method: "POST",
      methodFqn: "wix.table_reservations.reservation.v1.ReservationsService.CancelReservation",
      packageName: PACKAGE_NAME,
      url: resolveWixTableReservationsReservationV1ReservationsServiceUrl({
        protoPath: "/v1/reservations/{reservationId}/cancel",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "reservation.createdDate" },
            { path: "reservation.updatedDate" },
            { path: "reservation.details.startDate" },
            { path: "reservation.details.endDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __cancelReservation;
}
function deleteReservation(payload) {
  function __deleteReservation({ host }) {
    const metadata = {
      entityFqdn: "wix.table_reservations.v1.reservation",
      method: "DELETE",
      methodFqn: "wix.table_reservations.reservation.v1.ReservationsService.DeleteReservation",
      packageName: PACKAGE_NAME,
      url: resolveWixTableReservationsReservationV1ReservationsServiceUrl({
        protoPath: "/v1/reservations/{reservationId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __deleteReservation;
}
function listReservations(payload) {
  function __listReservations({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [{ path: "startDateFrom" }, { path: "startDateTo" }]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.table_reservations.v1.reservation",
      method: "GET",
      methodFqn: "wix.table_reservations.reservation.v1.ReservationsService.ListReservations",
      packageName: PACKAGE_NAME,
      url: resolveWixTableReservationsReservationV1ReservationsServiceUrl({
        protoPath: "/v1/reservations",
        data: serializedData,
        host
      }),
      params: toURLSearchParams(serializedData),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "reservations.createdDate" },
            { path: "reservations.updatedDate" },
            { path: "reservations.details.startDate" },
            { path: "reservations.details.endDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __listReservations;
}
function queryReservations(payload) {
  function __queryReservations({ host }) {
    const metadata = {
      entityFqdn: "wix.table_reservations.v1.reservation",
      method: "POST",
      methodFqn: "wix.table_reservations.reservation.v1.ReservationsService.QueryReservations",
      packageName: PACKAGE_NAME,
      url: resolveWixTableReservationsReservationV1ReservationsServiceUrl({
        protoPath: "/v1/reservations/query",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "reservations.createdDate" },
            { path: "reservations.updatedDate" },
            { path: "reservations.details.startDate" },
            { path: "reservations.details.endDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __queryReservations;
}
function searchReservations(payload) {
  function __searchReservations({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFloatToRESTFloat,
        paths: [
          { path: "search.aggregations.range.buckets.from" },
          { path: "search.aggregations.range.buckets.to" },
          {
            path: "search.aggregations.nested.nestedAggregations.range.buckets.from"
          },
          {
            path: "search.aggregations.nested.nestedAggregations.range.buckets.to"
          }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.table_reservations.v1.reservation",
      method: "POST",
      methodFqn: "wix.table_reservations.reservation.v1.ReservationsService.SearchReservations",
      packageName: PACKAGE_NAME,
      url: resolveWixTableReservationsReservationV1ReservationsServiceUrl({
        protoPath: "/v1/reservations/search",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "reservations.createdDate" },
            { path: "reservations.updatedDate" },
            { path: "reservations.details.startDate" },
            { path: "reservations.details.endDate" }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            { path: "aggregationData.results.ranges.results.from" },
            { path: "aggregationData.results.ranges.results.to" },
            {
              path: "aggregationData.results.groupedByValue.results.nestedResults.ranges.results.from"
            },
            {
              path: "aggregationData.results.groupedByValue.results.nestedResults.ranges.results.to"
            },
            {
              path: "aggregationData.results.nested.results.results.*.range.from"
            },
            {
              path: "aggregationData.results.nested.results.results.*.range.to"
            },
            { path: "aggregationData.results.scalar.value" },
            {
              path: "aggregationData.results.groupedByValue.results.nestedResults.scalar.value"
            },
            {
              path: "aggregationData.results.nested.results.results.*.scalar.value"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __searchReservations;
}
function bulkArchiveReservations(payload) {
  function __bulkArchiveReservations({ host }) {
    const metadata = {
      entityFqdn: "wix.table_reservations.v1.reservation",
      method: "POST",
      methodFqn: "wix.table_reservations.reservation.v1.ReservationsService.BulkArchiveReservations",
      packageName: PACKAGE_NAME,
      url: resolveWixTableReservationsReservationV1ReservationsServiceUrl({
        protoPath: "/v1/bulk/reservations/archive",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __bulkArchiveReservations;
}
function bulkUnArchiveReservations(payload) {
  function __bulkUnArchiveReservations({ host }) {
    const metadata = {
      entityFqdn: "wix.table_reservations.v1.reservation",
      method: "POST",
      methodFqn: "wix.table_reservations.reservation.v1.ReservationsService.BulkUnArchiveReservations",
      packageName: PACKAGE_NAME,
      url: resolveWixTableReservationsReservationV1ReservationsServiceUrl({
        protoPath: "/v1/bulk/reservations/unarchive",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __bulkUnArchiveReservations;
}

// src/table-reservations-v1-reservation-reservations.universal.ts
import { transformPaths as transformPaths2 } from "@wix/sdk-runtime/transformations/transform-paths";
var Status = /* @__PURE__ */ ((Status2) => {
  Status2["UNKNOWN"] = "UNKNOWN";
  Status2["HELD"] = "HELD";
  Status2["RESERVED"] = "RESERVED";
  Status2["CANCELED"] = "CANCELED";
  Status2["FINISHED"] = "FINISHED";
  Status2["NO_SHOW"] = "NO_SHOW";
  Status2["SEATED"] = "SEATED";
  Status2["REQUESTED"] = "REQUESTED";
  Status2["DECLINED"] = "DECLINED";
  Status2["PAYMENT_PENDING"] = "PAYMENT_PENDING";
  return Status2;
})(Status || {});
var Source = /* @__PURE__ */ ((Source2) => {
  Source2["UNKNOWN"] = "UNKNOWN";
  Source2["OFFLINE"] = "OFFLINE";
  Source2["ONLINE"] = "ONLINE";
  Source2["WALK_IN"] = "WALK_IN";
  return Source2;
})(Source || {});
var PaymentStatus = /* @__PURE__ */ ((PaymentStatus2) => {
  PaymentStatus2["UNKNOWN"] = "UNKNOWN";
  PaymentStatus2["FREE"] = "FREE";
  PaymentStatus2["NOT_PAID"] = "NOT_PAID";
  PaymentStatus2["PAID"] = "PAID";
  PaymentStatus2["PARTIALLY_REFUNDED"] = "PARTIALLY_REFUNDED";
  PaymentStatus2["FULLY_REFUNDED"] = "FULLY_REFUNDED";
  PaymentStatus2["PARTIALLY_PAID"] = "PARTIALLY_PAID";
  return PaymentStatus2;
})(PaymentStatus || {});
var TableCombinationConflictType = /* @__PURE__ */ ((TableCombinationConflictType2) => {
  TableCombinationConflictType2["UNKNOWN"] = "UNKNOWN";
  TableCombinationConflictType2["RESERVED"] = "RESERVED";
  TableCombinationConflictType2["TOO_BIG"] = "TOO_BIG";
  TableCombinationConflictType2["TOO_SMALL"] = "TOO_SMALL";
  TableCombinationConflictType2["OFFLINE_ONLY"] = "OFFLINE_ONLY";
  return TableCombinationConflictType2;
})(TableCombinationConflictType || {});
var Type = /* @__PURE__ */ ((Type2) => {
  Type2["UNKNOWN"] = "UNKNOWN";
  Type2["PARTY_PACING"] = "PARTY_PACING";
  Type2["SEAT_PACING"] = "SEAT_PACING";
  return Type2;
})(Type || {});
var Set = /* @__PURE__ */ ((Set2) => {
  Set2["PUBLIC"] = "PUBLIC";
  Set2["FULL"] = "FULL";
  return Set2;
})(Set || {});
var SortOrder = /* @__PURE__ */ ((SortOrder2) => {
  SortOrder2["ASC"] = "ASC";
  SortOrder2["DESC"] = "DESC";
  return SortOrder2;
})(SortOrder || {});
var SortType = /* @__PURE__ */ ((SortType2) => {
  SortType2["COUNT"] = "COUNT";
  SortType2["VALUE"] = "VALUE";
  return SortType2;
})(SortType || {});
var SortDirection = /* @__PURE__ */ ((SortDirection2) => {
  SortDirection2["DESC"] = "DESC";
  SortDirection2["ASC"] = "ASC";
  return SortDirection2;
})(SortDirection || {});
var MissingValues = /* @__PURE__ */ ((MissingValues2) => {
  MissingValues2["EXCLUDE"] = "EXCLUDE";
  MissingValues2["INCLUDE"] = "INCLUDE";
  return MissingValues2;
})(MissingValues || {});
var ScalarType = /* @__PURE__ */ ((ScalarType2) => {
  ScalarType2["UNKNOWN_SCALAR_TYPE"] = "UNKNOWN_SCALAR_TYPE";
  ScalarType2["COUNT_DISTINCT"] = "COUNT_DISTINCT";
  ScalarType2["MIN"] = "MIN";
  ScalarType2["MAX"] = "MAX";
  return ScalarType2;
})(ScalarType || {});
var NestedAggregationType = /* @__PURE__ */ ((NestedAggregationType2) => {
  NestedAggregationType2["UNKNOWN_AGGREGATION_TYPE"] = "UNKNOWN_AGGREGATION_TYPE";
  NestedAggregationType2["VALUE"] = "VALUE";
  NestedAggregationType2["RANGE"] = "RANGE";
  NestedAggregationType2["SCALAR"] = "SCALAR";
  NestedAggregationType2["DATE_HISTOGRAM"] = "DATE_HISTOGRAM";
  return NestedAggregationType2;
})(NestedAggregationType || {});
var Interval = /* @__PURE__ */ ((Interval2) => {
  Interval2["UNKNOWN_INTERVAL"] = "UNKNOWN_INTERVAL";
  Interval2["YEAR"] = "YEAR";
  Interval2["MONTH"] = "MONTH";
  Interval2["WEEK"] = "WEEK";
  Interval2["DAY"] = "DAY";
  Interval2["HOUR"] = "HOUR";
  Interval2["MINUTE"] = "MINUTE";
  Interval2["SECOND"] = "SECOND";
  return Interval2;
})(Interval || {});
var AggregationType = /* @__PURE__ */ ((AggregationType2) => {
  AggregationType2["UNKNOWN_AGGREGATION_TYPE"] = "UNKNOWN_AGGREGATION_TYPE";
  AggregationType2["VALUE"] = "VALUE";
  AggregationType2["RANGE"] = "RANGE";
  AggregationType2["SCALAR"] = "SCALAR";
  AggregationType2["DATE_HISTOGRAM"] = "DATE_HISTOGRAM";
  AggregationType2["NESTED"] = "NESTED";
  return AggregationType2;
})(AggregationType || {});
var Mode = /* @__PURE__ */ ((Mode2) => {
  Mode2["OR"] = "OR";
  Mode2["AND"] = "AND";
  return Mode2;
})(Mode || {});
var WebhookIdentityType = /* @__PURE__ */ ((WebhookIdentityType2) => {
  WebhookIdentityType2["UNKNOWN"] = "UNKNOWN";
  WebhookIdentityType2["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
  WebhookIdentityType2["MEMBER"] = "MEMBER";
  WebhookIdentityType2["WIX_USER"] = "WIX_USER";
  WebhookIdentityType2["APP"] = "APP";
  return WebhookIdentityType2;
})(WebhookIdentityType || {});
async function createReservation2(reservation, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    reservation,
    ignoreTableCombinationConflicts: options?.ignoreTableCombinationConflicts,
    ignoreReservationLocationConflicts: options?.ignoreReservationLocationConflicts
  });
  const reqOpts = createReservation(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data)?.reservation;
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          reservation: "$[0]",
          ignoreTableCombinationConflicts: "$[1].ignoreTableCombinationConflicts",
          ignoreReservationLocationConflicts: "$[1].ignoreReservationLocationConflicts"
        },
        singleArgumentUnchanged: false
      },
      ["reservation", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function getReservation2(reservationId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    reservationId,
    fieldsets: options?.fieldsets
  });
  const reqOpts = getReservation(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data)?.reservation;
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          reservationId: "$[0]",
          fieldsets: "$[1].fieldsets"
        },
        singleArgumentUnchanged: false
      },
      ["reservationId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function updateReservation2(_id, reservation, options) {
  const { httpClient, sideEffects } = arguments[3];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    reservation: { ...reservation, id: _id },
    ignoreTableCombinationConflicts: options?.ignoreTableCombinationConflicts,
    ignoreReservationLocationConflicts: options?.ignoreReservationLocationConflicts
  });
  const reqOpts = updateReservation(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data)?.reservation;
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: { reservation: "$[1]" },
        explicitPathsToArguments: {
          "reservation.id": "$[0]",
          ignoreTableCombinationConflicts: "$[2].ignoreTableCombinationConflicts",
          ignoreReservationLocationConflicts: "$[2].ignoreReservationLocationConflicts"
        },
        singleArgumentUnchanged: false
      },
      ["_id", "reservation", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function createHeldReservation2(reservationDetails) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    reservationDetails
  });
  const reqOpts = createHeldReservation(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { reservationDetails: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["reservationDetails"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function reserveReservation2(reservationId, reservee, revision) {
  const { httpClient, sideEffects } = arguments[3];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    reservationId,
    reservee,
    revision
  });
  const reqOpts = reserveReservation(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          reservationId: "$[0]",
          reservee: "$[1]",
          revision: "$[2]"
        },
        singleArgumentUnchanged: false
      },
      ["reservationId", "reservee", "revision"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function cancelReservation2(reservationId, revision, options) {
  const { httpClient, sideEffects } = arguments[3];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    reservationId,
    revision,
    phone: options?.phone
  });
  const reqOpts = cancelReservation(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          reservationId: "$[0]",
          revision: "$[1]",
          phone: "$[2].phone"
        },
        singleArgumentUnchanged: false
      },
      ["reservationId", "revision", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function deleteReservation2(reservationId) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    reservationId
  });
  const reqOpts = deleteReservation(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { reservationId: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["reservationId"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function listReservations2(options) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    paging: options?.paging,
    sort: options?.sort,
    startDateFrom: options?.startDateFrom,
    startDateTo: options?.startDateTo,
    status: options?.status
  });
  const reqOpts = listReservations(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          paging: "$[0].paging",
          sort: "$[0].sort",
          startDateFrom: "$[0].startDateFrom",
          startDateTo: "$[0].startDateTo",
          status: "$[0].status"
        },
        singleArgumentUnchanged: false
      },
      ["options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
function queryReservations2() {
  const { httpClient, sideEffects } = arguments[0];
  return queryBuilder({
    func: async (payload) => {
      const reqOpts = queryReservations(payload);
      sideEffects?.onSiteCall?.();
      try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return result;
      } catch (err) {
        sideEffects?.onError?.(err);
        throw err;
      }
    },
    requestTransformer: (query) => {
      const args = [query, {}];
      return renameKeysFromSDKRequestToRESTRequest({
        ...args?.[1],
        query: args?.[0]
      });
    },
    responseTransformer: ({
      data
    }) => {
      const transformedData = renameKeysFromRESTResponseToSDKResponse(
        transformPaths2(data, [])
      );
      return {
        items: transformedData?.reservations,
        pagingMetadata: transformedData?.pagingMetadata
      };
    },
    errorTransformer: (err) => {
      const transformedError = sdkTransformError(err, {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { query: "$[0]" },
        singleArgumentUnchanged: false
      });
      throw transformedError;
    },
    pagingMethod: "CURSOR",
    transformationPaths: {}
  });
}
async function searchReservations2(search) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({ search });
  const reqOpts = searchReservations(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { search: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["search"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function bulkArchiveReservations2(reservationIds) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    reservationIds
  });
  const reqOpts = bulkArchiveReservations(
    payload
  );
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { reservationIds: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["reservationIds"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function bulkUnArchiveReservations2(reservationIds) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    reservationIds
  });
  const reqOpts = bulkUnArchiveReservations(
    payload
  );
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { reservationIds: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["reservationIds"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}

// src/table-reservations-v1-reservation-reservations.public.ts
function createReservation3(httpClient) {
  return (reservation, options) => createReservation2(
    reservation,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function getReservation3(httpClient) {
  return (reservationId, options) => getReservation2(
    reservationId,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function updateReservation3(httpClient) {
  return (_id, reservation, options) => updateReservation2(
    _id,
    reservation,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function createHeldReservation3(httpClient) {
  return (reservationDetails) => createHeldReservation2(
    reservationDetails,
    // @ts-ignore
    { httpClient }
  );
}
function reserveReservation3(httpClient) {
  return (reservationId, reservee, revision) => reserveReservation2(
    reservationId,
    reservee,
    revision,
    // @ts-ignore
    { httpClient }
  );
}
function cancelReservation3(httpClient) {
  return (reservationId, revision, options) => cancelReservation2(
    reservationId,
    revision,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function deleteReservation3(httpClient) {
  return (reservationId) => deleteReservation2(
    reservationId,
    // @ts-ignore
    { httpClient }
  );
}
function listReservations3(httpClient) {
  return (options) => listReservations2(
    options,
    // @ts-ignore
    { httpClient }
  );
}
function queryReservations3(httpClient) {
  return () => queryReservations2(
    // @ts-ignore
    { httpClient }
  );
}
function searchReservations3(httpClient) {
  return (search) => searchReservations2(
    search,
    // @ts-ignore
    { httpClient }
  );
}
function bulkArchiveReservations3(httpClient) {
  return (reservationIds) => bulkArchiveReservations2(
    reservationIds,
    // @ts-ignore
    { httpClient }
  );
}
function bulkUnArchiveReservations3(httpClient) {
  return (reservationIds) => bulkUnArchiveReservations2(
    reservationIds,
    // @ts-ignore
    { httpClient }
  );
}
var onReservationCreated = EventDefinition(
  "wix.table_reservations.v1.reservation_created",
  true,
  (event) => renameKeysFromRESTResponseToSDKResponse2(
    transformPaths3(event, [
      {
        transformFn: transformRESTTimestampToSDKTimestamp2,
        paths: [
          { path: "entity.createdDate" },
          { path: "entity.updatedDate" },
          { path: "entity.details.startDate" },
          { path: "entity.details.endDate" },
          { path: "metadata.eventTime" }
        ]
      }
    ])
  )
)();
var onReservationDeleted = EventDefinition(
  "wix.table_reservations.v1.reservation_deleted",
  true,
  (event) => renameKeysFromRESTResponseToSDKResponse2(
    transformPaths3(event, [
      {
        transformFn: transformRESTTimestampToSDKTimestamp2,
        paths: [
          { path: "undefined.createdDate" },
          { path: "undefined.updatedDate" },
          { path: "undefined.details.startDate" },
          { path: "undefined.details.endDate" },
          { path: "metadata.eventTime" }
        ]
      }
    ])
  )
)();
var onReservationUpdated = EventDefinition(
  "wix.table_reservations.v1.reservation_updated",
  true,
  (event) => renameKeysFromRESTResponseToSDKResponse2(
    transformPaths3(event, [
      {
        transformFn: transformRESTTimestampToSDKTimestamp2,
        paths: [
          { path: "entity.createdDate" },
          { path: "entity.updatedDate" },
          { path: "entity.details.startDate" },
          { path: "entity.details.endDate" },
          { path: "metadata.eventTime" }
        ]
      }
    ])
  )
)();

// src/table-reservations-v1-reservation-reservations.context.ts
import { createRESTModule } from "@wix/sdk-runtime/rest-modules";
import { createEventModule } from "@wix/sdk-runtime/event-definition-modules";
var createReservation4 = /* @__PURE__ */ createRESTModule(createReservation3);
var getReservation4 = /* @__PURE__ */ createRESTModule(getReservation3);
var updateReservation4 = /* @__PURE__ */ createRESTModule(updateReservation3);
var createHeldReservation4 = /* @__PURE__ */ createRESTModule(createHeldReservation3);
var reserveReservation4 = /* @__PURE__ */ createRESTModule(reserveReservation3);
var cancelReservation4 = /* @__PURE__ */ createRESTModule(cancelReservation3);
var deleteReservation4 = /* @__PURE__ */ createRESTModule(deleteReservation3);
var listReservations4 = /* @__PURE__ */ createRESTModule(listReservations3);
var queryReservations4 = /* @__PURE__ */ createRESTModule(queryReservations3);
var searchReservations4 = /* @__PURE__ */ createRESTModule(searchReservations3);
var bulkArchiveReservations4 = /* @__PURE__ */ createRESTModule(bulkArchiveReservations3);
var bulkUnArchiveReservations4 = /* @__PURE__ */ createRESTModule(bulkUnArchiveReservations3);
var onReservationCreated2 = createEventModule(onReservationCreated);
var onReservationDeleted2 = createEventModule(onReservationDeleted);
var onReservationUpdated2 = createEventModule(onReservationUpdated);
export {
  AggregationType,
  Interval,
  MissingValues,
  Mode,
  NestedAggregationType,
  PaymentStatus,
  ScalarType,
  Set,
  SortDirection,
  SortOrder,
  SortType,
  Source,
  Status,
  TableCombinationConflictType,
  Type,
  WebhookIdentityType,
  bulkArchiveReservations4 as bulkArchiveReservations,
  bulkUnArchiveReservations4 as bulkUnArchiveReservations,
  cancelReservation4 as cancelReservation,
  createHeldReservation4 as createHeldReservation,
  createReservation4 as createReservation,
  deleteReservation4 as deleteReservation,
  getReservation4 as getReservation,
  listReservations4 as listReservations,
  onReservationCreated2 as onReservationCreated,
  onReservationDeleted2 as onReservationDeleted,
  onReservationUpdated2 as onReservationUpdated,
  queryReservations4 as queryReservations,
  reserveReservation4 as reserveReservation,
  searchReservations4 as searchReservations,
  updateReservation4 as updateReservation
};
//# sourceMappingURL=index.mjs.map