import { V as CreateReservationRequest$1, X as CreateReservationResponse$1, $ as GetReservationRequest$1, a0 as GetReservationResponse$1, a1 as UpdateReservationRequest$1, a2 as UpdateReservationResponse$1, a3 as CreateHeldReservationRequest$1, b as CreateHeldReservationResponse$1, a4 as ReserveReservationRequest$1, d as ReserveReservationResponse$1, a5 as CancelReservationRequest$1, f as CancelReservationResponse$1, a7 as DeleteReservationRequest$1, a8 as DeleteReservationResponse$1, a9 as ListReservationsRequest$1, g as ListReservationsResponse$1, ae as QueryReservationsRequest$1, ah as QueryReservationsResponse$1, ai as SearchReservationsRequest$1, S as SearchReservationsResponse$1, aT as BulkArchiveReservationsRequest$1, B as BulkArchiveReservationsResponse$1, aY as BulkUnArchiveReservationsRequest$1, j as BulkUnArchiveReservationsResponse$1 } from './table-reservations-v1-reservation-reservations.universal-iVx94_Pd.mjs';
import '@wix/sdk-types';

/** The reservation domain object. */
interface Reservation {
    /**
     * Reservation ID.
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /**
     * Status of the reservation.
     *
     * See the Reservation Lifecycle article([REST](https://dev.wix.com/docs/rest/api-reference/wix-restaurants/reservations/reservations/the-reservation-lifecycle) | [SDK](https://dev.wix.com/docs/sdk/backend-modules/table-reservations/reservations/the-reservation-lifecycle)) for an explanation of the role of statuses in the reservation lifecycle.
     */
    status?: StatusWithLiterals;
    /**
     * Reservation source.
     *
     * This indicates how the reservation was made.
     */
    source?: SourceWithLiterals;
    /** Reservation details. */
    details?: Details;
    /**
     * Information about the person the reservation is being made for.
     *
     * A reservation created with any `source` other than `WALK_IN` requires the `reservation.reservee.phone` and `reservation.reservee.firstName` fields.
     * Attempting to create a reservation without these fields results in an error.
     */
    reservee?: Reservee;
    /**
     * Information about the person making the reservation.
     *
     * This field is required if the reservation's `status` is anything other than `WALK_IN`.
     * @readonly
     */
    reservedBy?: ReservedBy;
    /**
     * Team message.
     *
     * A message for the restaurant staff containing any additional information regarding the reservation, such as special requirements for the guests.
     * @maxLength 10000
     */
    teamMessage?: string | null;
    /**
     * Date and time the reservation was created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Date and time the reservation was changed.
     * @readonly
     */
    updatedDate?: Date | null;
    /**
     * Revision number, which increments by 1 each time the reservation is updated.
     * To prevent conflicting changes, the current revision must be specified when updating the reservation.
     *
     * Ignored when creating a reservation.
     * @readonly
     */
    revision?: string | null;
    /**
     * The reason the reservation was declined.
     * @maxLength 1000
     */
    declineReason?: string | null;
    /**
     * Payment status.
     * @readonly
     */
    paymentStatus?: PaymentStatusWithLiterals;
    /**
     * Custom field data for the reservation object.
     *
     * [Extended fields](https://dev.wix.com/docs/rest/articles/getting-started/extended-fields) must be configured in the app dashboard before they can be accessed with API calls.
     */
    extendedFields?: ExtendedFields;
}
/** Tables used for the reservation. If you don't specify a `tables` object, the server attempts to assign tables automatically. */
interface Tables {
    /**
     * IDs of tables used for this reservation. If you don't specify an `ids` array, or you specify an empty array, no tables are assigned.
     * @format GUID
     * @maxSize 100
     */
    ids?: string[];
}
declare enum Status {
    /** Undefined reservation status. */
    UNKNOWN = "UNKNOWN",
    /** A customer has begun the reservation flow, a temporary reservation is created and will expire in 10 minutes unless the customer moves forward with the reservation flow. This phase temporarily reserves the required number of seats and tables for a given party size at a chosen time while a customer enters details and/or confirms their reservation request. */
    HELD = "HELD",
    /** The reservation is confirmed. */
    RESERVED = "RESERVED",
    /** The reservation is canceled. */
    CANCELED = "CANCELED",
    /** The reservation completed successfully. */
    FINISHED = "FINISHED",
    /** The customer didn't show up for their reservation. */
    NO_SHOW = "NO_SHOW",
    /** The customer is currently occupying the table. */
    SEATED = "SEATED",
    /** A customer finished requesting this reservation, meaning they have added all necessary details and confirmed the request. Restaurant staff can now either approve or decline the reservation request. */
    REQUESTED = "REQUESTED",
    /** The restaurant’s owner or staff declined the customer’s request to make the reservation. */
    DECLINED = "DECLINED",
    /** A customer has begun the checkout flow, the temporary reservation is moved to this status and will expire in 10 minutes from the created time, during which time the reservee should pay. This status is set automatically when the reserve reservation endpoint is called for a reservation in `HELD` status and payment is needed. After payment is completed status will be changed automatically to `RESERVED`. */
    PAYMENT_PENDING = "PAYMENT_PENDING"
}
/** @enumType */
type StatusWithLiterals = Status | 'UNKNOWN' | 'HELD' | 'RESERVED' | 'CANCELED' | 'FINISHED' | 'NO_SHOW' | 'SEATED' | 'REQUESTED' | 'DECLINED' | 'PAYMENT_PENDING';
declare enum Source {
    /** Undefined reservation source. */
    UNKNOWN = "UNKNOWN",
    /** The reservation was made by a restaurant employee, for example when a customer calls to make a reservation. */
    OFFLINE = "OFFLINE",
    /** The reservation was made through a website or app. */
    ONLINE = "ONLINE",
    /** The reservation was made by a restaurant employee when the customer arrived at the restaurant without a prior reservation. */
    WALK_IN = "WALK_IN"
}
/** @enumType */
type SourceWithLiterals = Source | 'UNKNOWN' | 'OFFLINE' | 'ONLINE' | 'WALK_IN';
/** Reservation details. */
interface Details {
    /**
     * ID of the reservation location at which this reservation will be made.
     * @format GUID
     */
    reservationLocationId?: string | null;
    /**
     * IDs of tables used for this reservation.
     * @format GUID
     * @maxSize 100
     * @deprecated
     * @replacedBy tables
     * @targetRemovalDate 2024-12-31
     */
    tableIds?: string[] | null;
    /** Tables used for this reservation. */
    tables?: Tables;
    /** Start date and time of the reservation. */
    startDate?: Date | null;
    /** End date and time of the reservation. */
    endDate?: Date | null;
    /**
     * Party size.
     * @min 1
     * @max 1000
     */
    partySize?: number | null;
}
/** The person the reservation is being made for. */
interface Reservee {
    /**
     * First name.
     *
     * This field is required if the reservation's `status` is anything other than `WALK_IN`.
     * @maxLength 1000
     */
    firstName?: string | null;
    /**
     * Last name.
     * @maxLength 1000
     */
    lastName?: string | null;
    /**
     * Email address.
     * @format EMAIL
     */
    email?: string | null;
    /**
     * Phone number.
     *
     * This property should begin with a +, followed by the country code, and then the rest of the phone number. For example, `"+972555555555"`.
     *
     * This field is required if the reservation's `status` is anything other than `WALK_IN`.
     * @format PHONE
     */
    phone?: string | null;
    /** Whether the reservee has given marketing consent. */
    marketingConsent?: boolean | null;
    /**
     * Custom fields for the reservee in key-value pairs.
     *
     * The key is the custom field's ID, and the value is the custom field's value. For example, a custom field for allergies might have the key-value pair `f4283b2d-6340-4cf9-bae7-8769e6b62127 : "Nuts, Seafood"`.
     *
     * Empty fields are not returned.
     */
    customFields?: Record<string, any> | null;
    /**
     * Contact ID. If a contact with this ID does not exist on the site, one will be created.
     * @format GUID
     * @readonly
     */
    contactId?: string | null;
}
/** A person making reservation. */
interface ReservedBy {
    /**
     * Contact ID for the person who made the reservation. If a contact with this ID does not exist on the site, one will be created.
     * @format GUID
     * @readonly
     */
    contactId?: string | null;
}
declare enum PaymentStatus {
    /** Undefined payment status. */
    UNKNOWN = "UNKNOWN",
    /** A reservation is free of charge. */
    FREE = "FREE",
    /** Payment is not received yet. */
    NOT_PAID = "NOT_PAID",
    /** The corresponding reservation order was fully paid. */
    PAID = "PAID",
    /** The corresponding reservation order was refunded, but the refund amount is less than the order total price. */
    PARTIALLY_REFUNDED = "PARTIALLY_REFUNDED",
    /** The corresponding reservation order was fully refunded. The refund amount equals the total price. */
    FULLY_REFUNDED = "FULLY_REFUNDED",
    /** The corresponding reservation order was partially paid. */
    PARTIALLY_PAID = "PARTIALLY_PAID"
}
/** @enumType */
type PaymentStatusWithLiterals = PaymentStatus | 'UNKNOWN' | 'FREE' | 'NOT_PAID' | 'PAID' | 'PARTIALLY_REFUNDED' | 'FULLY_REFUNDED' | 'PARTIALLY_PAID';
interface ExtendedFields {
    /**
     * Extended field data. Each key corresponds to the namespace of the app that created the extended fields.
     * The value of each key is structured according to the schema defined when the extended fields were configured.
     *
     * You can only access fields for which you have the appropriate permissions.
     *
     * Learn more about [extended fields](https://dev.wix.com/docs/rest/articles/getting-started/extended-fields).
     */
    namespaces?: Record<string, Record<string, any>>;
}
interface CreateReservationRequest {
    /** Reservation details. */
    reservation: Reservation;
    /**
     * Ignore table combination conflicts of the types specified in the array. This ensures that the reservation is created even if the given conflicts would normally prevent it.
     *
     * Possible values:
     * * `"RESERVED"`: One or more of the chosen tables are already reserved.
     * * `"TOO_BIG"`: The party is too big for the selected table.
     * * `"TOO_SMALL"`: The party is too small for the selected table.
     * * `"OFFLINE_ONLY"`: The restaurant does not allow online reservations.
     * @maxSize 10
     */
    ignoreTableCombinationConflicts?: TableCombinationConflictTypeWithLiterals[];
    /**
     * Ignored reservation location conflicts of the types specified in the array. This ensures that the reservation is created even if the given conflicts would normally prevent it.
     *
     * Possible values:
     * * `"PARTY_PACING"`: The restaurant cannot accommodate a party of the given size according to party pacing settings.
     * * `"SEAT_PACING"`: The required number of seats are unavailable according to seat pacing settings.
     * @maxSize 10
     */
    ignoreReservationLocationConflicts?: TypeWithLiterals[];
}
declare enum TableCombinationConflictType {
    /** Undefined conflict type. */
    UNKNOWN = "UNKNOWN",
    /** One or more of the chosen tables are already reserved. */
    RESERVED = "RESERVED",
    /** The party is too big for the selected table. */
    TOO_BIG = "TOO_BIG",
    /** The party is too small for the selected table. */
    TOO_SMALL = "TOO_SMALL",
    /** The restaurant does not allow online reservations. */
    OFFLINE_ONLY = "OFFLINE_ONLY"
}
/** @enumType */
type TableCombinationConflictTypeWithLiterals = TableCombinationConflictType | 'UNKNOWN' | 'RESERVED' | 'TOO_BIG' | 'TOO_SMALL' | 'OFFLINE_ONLY';
declare enum Type {
    /** Undefined reservation location conflict type. */
    UNKNOWN = "UNKNOWN",
    /** The restaurant cannot accommodate a party of the given size according to party pacing settings. */
    PARTY_PACING = "PARTY_PACING",
    /** The required number of seats are unavailable according to seat pacing settings. */
    SEAT_PACING = "SEAT_PACING"
}
/** @enumType */
type TypeWithLiterals = Type | 'UNKNOWN' | 'PARTY_PACING' | 'SEAT_PACING';
interface CreateReservationResponse {
    /** Reservation. */
    reservation?: Reservation;
}
interface GetReservationRequest {
    /**
     * Reservation ID.
     * @format GUID
     */
    reservationId: string;
    /**
     * Array of named, predefined sets of projected fields to be returned.
     * Default: If `fields` is omitted from the request, `PUBLIC`.
     * @maxSize 1
     */
    fieldsets?: SetWithLiterals[];
}
declare enum Set {
    /**
     * Returns `id`, `status`, `details.reservationLocationId`, `details.startDate`, `details.endDate`, `details.partySize`, `createdDate`, `revision`, `declineReason`,
     * `configuration.reservationForm.customFieldDefinitions`, `configuration.reservationForm.lastNameRequired`, `configuration.reservationForm.emailRequired`, `configuration.reservationForm.emailMarketingCheckbox`.
     */
    PUBLIC = "PUBLIC",
    /** Returns all fields. */
    FULL = "FULL"
}
/** @enumType */
type SetWithLiterals = Set | 'PUBLIC' | 'FULL';
interface GetReservationResponse {
    /** Reservation. */
    reservation?: Reservation;
}
interface UpdateReservationRequest {
    /** Reservation information to update. */
    reservation: Reservation;
    /**
     * Ignore table combination conflicts of the types included in the array. This ensures that the reservation is updated even if the given conflicts would normally prevent it.
     * @maxSize 10
     */
    ignoreTableCombinationConflicts?: TableCombinationConflictTypeWithLiterals[];
    /** @maxSize 10 */
    ignoreReservationLocationConflicts?: TypeWithLiterals[];
}
interface UpdateReservationResponse {
    /** Reservation. */
    reservation?: Reservation;
}
interface CreateHeldReservationRequest {
    /** Held reservation information to update. */
    reservationDetails: HeldReservationDetails;
}
/** Reservation details when create reservation in status HELD. */
interface HeldReservationDetails {
    /**
     * ID of the reservation location where the reservation is made.
     * @format GUID
     */
    reservationLocationId?: string | null;
    /** Start date and time of the reservation. */
    startDate?: Date | null;
    /**
     * Party size.
     * @min 1
     * @max 1000
     */
    partySize?: number | null;
}
interface CreateHeldReservationResponse {
    /** Reservation. */
    reservation?: Reservation;
}
interface ReserveReservationRequest {
    /**
     * Reservation ID.
     * @format GUID
     */
    reservationId: string;
    /** Reservee details. */
    reservee: Reservee;
    /**
     * Revision number.
     *
     * Specify the existing `revision` to prevent conflicting updates to reservations.
     */
    revision: string | null;
}
interface ReserveReservationResponse {
    /** Reservation. */
    reservation?: Reservation;
}
interface CancelReservationRequest {
    /**
     * Reservation ID.
     * @format GUID
     */
    reservationId: string;
    /**
     * Revision number.
     *
     * Specify the existing `revision` to prevent conflicting updates to reservations.
     */
    revision: string | null;
    /**
     * The phone number that was provided when the reservation was created.
     *
     * This is required for reservations with any `source` other than `WALK_IN`.
     *
     * This requirement provides additional security by ensuring that the canceling party knows both the reservation's `reservationId` and the reservee's `phone`.
     * @format PHONE
     */
    phone?: string | null;
}
interface CancelReservationResponse {
    /** Reservation. */
    reservation?: Reservation;
}
interface DeleteReservationRequest {
    /**
     * Reservation ID.
     * @format GUID
     */
    reservationId: string;
}
interface DeleteReservationResponse {
}
interface ListReservationsRequest {
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    paging?: CursorPaging;
    /** Defines how reservations in the response are sorted. */
    sort?: Sorting;
    /** Only reservations starting after this date are returned. */
    startDateFrom?: Date | null;
    /** Only reservations starting before this date are returned. */
    startDateTo?: Date | null;
    /** Only reservations with this status are returned. */
    status?: StatusWithLiterals;
}
interface CursorPaging {
    /**
     * Number of items to load.
     * @max 100
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * You can get the relevant cursor token
     * from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     */
    cursor?: string | null;
}
interface Sorting {
    /** Name of the field to sort by. */
    fieldName?: string;
    /**
     * Sort order.
     * Default: `ASC`.
     */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    /** Sort by ascending order. */
    ASC = "ASC",
    /** Sort by descending order. */
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface ListReservationsResponse {
    /** List of reservations. */
    reservations?: Reservation[];
    /** Metadata for the paginated results. */
    pagingMetadata?: CursorPagingMetadata;
}
interface CursorPagingMetadata {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    cursors?: Cursors;
    /**
     * Indicates if there are more results after the current page.
     * If `true`, another page of results can be retrieved.
     * If `false`, this is the last page.
     */
    hasNext?: boolean | null;
}
interface Cursors {
    /** Cursor pointing to next page in the list of results. */
    next?: string | null;
    /** Cursor pointing to previous page in the list of results. */
    prev?: string | null;
}
interface QueryReservationsRequest {
    /** Query to select reservations. */
    query: CursorQuery;
}
interface CursorQuery extends CursorQueryPagingMethodOneOf {
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
    /**
     * Filter object in the following format:
     * `"filter" : {
     * "fieldName1": "value1",
     * "fieldName2":{"$operator":"value2"}
     * }`
     *
     * For a detailed list of supported operations, see the [Supported Filters and Sorting](https://dev.wix.com/docs/rest/api-reference/wix-restaurants/reservations/reservations/sorting-filtering-and-search) article.
     * To learn how to query reservations, see [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language).
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object in the following format:
     * `[{"fieldName":"sortField1","order":"ASC"},{"fieldName":"sortField2","order":"DESC"}]`
     */
    sort?: Sorting[];
}
/** @oneof */
interface CursorQueryPagingMethodOneOf {
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
}
interface QueryReservationsResponse {
    /** List of reservations. */
    reservations?: Reservation[];
    /** Metadata for the paginated results. */
    pagingMetadata?: CursorPagingMetadata;
}
interface SearchReservationsRequest {
    /** Search query. */
    search: CursorSearch;
}
interface CursorSearch extends CursorSearchPagingMethodOneOf {
    /** Cursor pointing to a page of results. Can't be used together with 'paging'. 'cursorPaging.cursor' can't be used together with 'filter' or 'sort'. */
    cursorPaging?: CursorPaging;
    /**
     * Filter object in the following format:
     * `"filter" : {
     * "fieldName1": "value1",
     * "fieldName2":{"$operator":"value2"}
     * }`
     * For a detailed list of supported operations, see the [Supported Filters and Sorting](https://dev.wix.com/docs/rest/api-reference/wix-restaurants/reservations/reservations/sorting-filtering-and-search) article.
     */
    filter?: Record<string, any> | null;
    /**
     * Sort object in the following format:
     * `[{"fieldName":"sortField1","order":"ASC"},{"fieldName":"sortField2","order":"DESC"}]`
     * @maxSize 100
     */
    sort?: Sorting[];
    /**
     * A search method for grouping data into various categories (facets) and providing summaries for each category.
     * For example, use aggregations to allow site visitors to narrow down their search results by selecting specific reservation statuses, party sizes, etc.
     * @maxSize 100
     */
    aggregations?: Aggregation[];
    /** Free text to match in searchable fields. */
    search?: SearchDetails;
    /**
     * Time zone to adjust date-time-based filters and aggregations. ISO 8601 or IANA time zone database format.
     * @maxLength 100
     */
    timeZone?: string | null;
}
/** @oneof */
interface CursorSearchPagingMethodOneOf {
    /** Cursor pointing to a page of results. Can't be used together with 'paging'. 'cursorPaging.cursor' can't be used together with 'filter' or 'sort'. */
    cursorPaging?: CursorPaging;
}
interface Aggregation extends AggregationKindOneOf {
    /** A value aggregation calculates metrics such as "count" for specific fields within a dataset, providing insights into the overall distribution and key statistics of those values. For example, use a value aggregation to get the number of reservations (count) of each status that have been made on the site. */
    value?: ValueAggregation;
    /** A range aggregation calculates the count of the values from the specified field in the dataset that fall within the range of each bucket you define. For example, use a range aggregation to compare the number of reservations made for parties of 4 or less to the number of reservations made for parties with 5 or more. */
    range?: RangeAggregation;
    /** A scalar aggregation calculates a single numerical value from a dataset, such as the total sum, average, min, or max, summarizing the dataset into one key metric. For example, use a scalar aggregation to get the average part size of reservations made on a site. */
    scalar?: ScalarAggregation;
    /** A date histogram calculates the count of time values from the specified field in the dataset that fall within each time interval you define (hour, day, week, etc.) For example, use a date histogram to find how many reservations have been made at a restaurant each week. */
    dateHistogram?: DateHistogramAggregation;
    /**
     * A nested aggregation is applied within the results of another aggregation. Rather than aggregating directly on the primary dataset, first group data using one aggregation and then apply another aggregation within each group. It allows for more complex analyses where you can summarize data at different levels of detail or hierarchy.
     * For example, to get the number of reservations by party size for each week, first perform a date histogram aggregation on `details.startDate` with the interval `WEEK`, and a second value aggregation on `details.partySize`.
     */
    nested?: NestedAggregation;
    /** @maxLength 1000 */
    name?: string | null;
    type?: AggregationTypeWithLiterals;
    /** @maxLength 1000 */
    fieldPath?: string;
}
/** @oneof */
interface AggregationKindOneOf {
    /** A value aggregation calculates metrics such as "count" for specific fields within a dataset, providing insights into the overall distribution and key statistics of those values. For example, use a value aggregation to get the number of reservations (count) of each status that have been made on the site. */
    value?: ValueAggregation;
    /** A range aggregation calculates the count of the values from the specified field in the dataset that fall within the range of each bucket you define. For example, use a range aggregation to compare the number of reservations made for parties of 4 or less to the number of reservations made for parties with 5 or more. */
    range?: RangeAggregation;
    /** A scalar aggregation calculates a single numerical value from a dataset, such as the total sum, average, min, or max, summarizing the dataset into one key metric. For example, use a scalar aggregation to get the average part size of reservations made on a site. */
    scalar?: ScalarAggregation;
    /** A date histogram calculates the count of time values from the specified field in the dataset that fall within each time interval you define (hour, day, week, etc.) For example, use a date histogram to find how many reservations have been made at a restaurant each week. */
    dateHistogram?: DateHistogramAggregation;
    /**
     * A nested aggregation is applied within the results of another aggregation. Rather than aggregating directly on the primary dataset, first group data using one aggregation and then apply another aggregation within each group. It allows for more complex analyses where you can summarize data at different levels of detail or hierarchy.
     * For example, to get the number of reservations by party size for each week, first perform a date histogram aggregation on `details.startDate` with the interval `WEEK`, and a second value aggregation on `details.partySize`.
     */
    nested?: NestedAggregation;
}
interface RangeBucket {
    /** Inclusive lower bound of the range. Required if `to` is not provided. */
    from?: number | null;
    /** Exclusive upper bound of the range. Required if `from` is not provided. */
    to?: number | null;
}
declare enum SortType {
    /** Sort by number of matches. */
    COUNT = "COUNT",
    /** Sort by value of the field alphabetically. */
    VALUE = "VALUE"
}
/** @enumType */
type SortTypeWithLiterals = SortType | 'COUNT' | 'VALUE';
declare enum SortDirection {
    /** Sort in descending order. */
    DESC = "DESC",
    /** Sort in ascending order. */
    ASC = "ASC"
}
/** @enumType */
type SortDirectionWithLiterals = SortDirection | 'DESC' | 'ASC';
declare enum MissingValues {
    /** Exclude missing values from the aggregation results */
    EXCLUDE = "EXCLUDE",
    /** Include missing values in the aggregation results */
    INCLUDE = "INCLUDE"
}
/** @enumType */
type MissingValuesWithLiterals = MissingValues | 'EXCLUDE' | 'INCLUDE';
interface IncludeMissingValuesOptions {
    /**
     * Specify a custom name for the bucket containing the missing values. Defaults are "N/A" for strings, "0" for integers, and "false" for booleans.
     * @maxLength 1000
     */
    addToBucket?: string;
}
declare enum ScalarType {
    /** Undefined scalar type. */
    UNKNOWN_SCALAR_TYPE = "UNKNOWN_SCALAR_TYPE",
    /** Count of distinct values. */
    COUNT_DISTINCT = "COUNT_DISTINCT",
    /** Minimum value. */
    MIN = "MIN",
    /** Maximum value. */
    MAX = "MAX"
}
/** @enumType */
type ScalarTypeWithLiterals = ScalarType | 'UNKNOWN_SCALAR_TYPE' | 'COUNT_DISTINCT' | 'MIN' | 'MAX';
declare enum NestedAggregationType {
    /** Undefined aggregation type. */
    UNKNOWN_AGGREGATION_TYPE = "UNKNOWN_AGGREGATION_TYPE",
    /** An aggregation where result buckets are dynamically built - one per unique value. */
    VALUE = "VALUE",
    /** An aggregation where you can define a set of ranges - each representing a bucket. */
    RANGE = "RANGE",
    /** A single-value metric aggregation - such as min, max, sum, and avg. */
    SCALAR = "SCALAR",
    /** An aggregation where result buckets are dynamically built - one per time interval such as hour, day, or week. */
    DATE_HISTOGRAM = "DATE_HISTOGRAM"
}
/** @enumType */
type NestedAggregationTypeWithLiterals = NestedAggregationType | 'UNKNOWN_AGGREGATION_TYPE' | 'VALUE' | 'RANGE' | 'SCALAR' | 'DATE_HISTOGRAM';
interface ValueAggregation extends ValueAggregationOptionsOneOf {
    /** Options for including missing values in results. */
    includeOptions?: IncludeMissingValuesOptions;
    /** Whether to sort by the number of matches or the value of the field. */
    sortType?: SortTypeWithLiterals;
    /** Whether to sort in ascending or descending order. */
    sortDirection?: SortDirectionWithLiterals;
    /**
     * Number of aggregation results to return.
     * Min: `1`
     * Max: `250`
     * Default: `10`
     */
    limit?: number | null;
    /**
     * Whether missing values should be included or excluded from the aggregation results.
     * Default: `EXCLUDE`.
     */
    missingValues?: MissingValuesWithLiterals;
}
/** @oneof */
interface ValueAggregationOptionsOneOf {
    /** Options for including missing values in results. */
    includeOptions?: IncludeMissingValuesOptions;
}
interface RangeAggregation {
    /**
     * List of range buckets. During aggregation each entity will be placed in the first bucket its value falls into based on the provided range bounds.
     * @maxSize 1000
     */
    buckets?: RangeBucket[];
}
interface ScalarAggregation {
    /** Operation type for the scalar aggregation. */
    type?: ScalarTypeWithLiterals;
}
interface DateHistogramAggregation {
    /** Interval for date histogram aggregation. */
    interval?: IntervalWithLiterals;
}
declare enum Interval {
    UNKNOWN_INTERVAL = "UNKNOWN_INTERVAL",
    YEAR = "YEAR",
    MONTH = "MONTH",
    WEEK = "WEEK",
    DAY = "DAY",
    HOUR = "HOUR",
    MINUTE = "MINUTE",
    SECOND = "SECOND"
}
/** @enumType */
type IntervalWithLiterals = Interval | 'UNKNOWN_INTERVAL' | 'YEAR' | 'MONTH' | 'WEEK' | 'DAY' | 'HOUR' | 'MINUTE' | 'SECOND';
interface NestedAggregationItem extends NestedAggregationItemKindOneOf {
    /** A value aggregation calculates metrics such as "count" for specific fields within a dataset, providing insights into the overall distribution and key statistics of those values. For example, use a value aggregation to get the number of reservations (count) of each status that have been made on the site. */
    value?: ValueAggregation;
    /** A range aggregation calculates the count of the values from the specified field in the dataset that fall within the range of each bucket you define. For example, use a range aggregation to compare the number of reservations made for parties of 4 or less to the number of reservations made for parties with 5 or more. */
    range?: RangeAggregation;
    /** A scalar aggregation calculates a single numerical value from a dataset, such as the total sum, average, min, or max, summarizing the dataset into one key metric. For example, use a scalar aggregation to get the average part size of reservations made on a site. */
    scalar?: ScalarAggregation;
    /** A date histogram calculates the count of time values from the specified field in the dataset that fall within each time interval you define (hour, day, week, etc.) For example, use a date histogram to find how many reservations have been made at a restaurant each week. */
    dateHistogram?: DateHistogramAggregation;
    /**
     * Aggregation name displayed in the return.
     * @maxLength 1000
     */
    name?: string | null;
    /** Type of aggregation to perform. */
    type?: NestedAggregationTypeWithLiterals;
    /** Field to aggregate by. */
    fieldPath?: string;
}
/** @oneof */
interface NestedAggregationItemKindOneOf {
    /** A value aggregation calculates metrics such as "count" for specific fields within a dataset, providing insights into the overall distribution and key statistics of those values. For example, use a value aggregation to get the number of reservations (count) of each status that have been made on the site. */
    value?: ValueAggregation;
    /** A range aggregation calculates the count of the values from the specified field in the dataset that fall within the range of each bucket you define. For example, use a range aggregation to compare the number of reservations made for parties of 4 or less to the number of reservations made for parties with 5 or more. */
    range?: RangeAggregation;
    /** A scalar aggregation calculates a single numerical value from a dataset, such as the total sum, average, min, or max, summarizing the dataset into one key metric. For example, use a scalar aggregation to get the average part size of reservations made on a site. */
    scalar?: ScalarAggregation;
    /** A date histogram calculates the count of time values from the specified field in the dataset that fall within each time interval you define (hour, day, week, etc.) For example, use a date histogram to find how many reservations have been made at a restaurant each week. */
    dateHistogram?: DateHistogramAggregation;
}
declare enum AggregationType {
    /** Undefined aggregation type. */
    UNKNOWN_AGGREGATION_TYPE = "UNKNOWN_AGGREGATION_TYPE",
    /** An aggregation where result buckets are dynamically built - one per unique value. */
    VALUE = "VALUE",
    /** An aggregation where you can define a set of ranges - each representing a bucket. */
    RANGE = "RANGE",
    /** A single-value metric aggregation - such as min, max, sum, or avg. */
    SCALAR = "SCALAR",
    /** An aggregation where result buckets are dynamically built - one per time interval such as hour, day, or week. */
    DATE_HISTOGRAM = "DATE_HISTOGRAM",
    /** Multi-level aggregation, where each next aggregation is nested within the previous one. */
    NESTED = "NESTED"
}
/** @enumType */
type AggregationTypeWithLiterals = AggregationType | 'UNKNOWN_AGGREGATION_TYPE' | 'VALUE' | 'RANGE' | 'SCALAR' | 'DATE_HISTOGRAM' | 'NESTED';
interface NestedAggregation {
    /**
     * Flattened list of aggregations, where each aggregation is nested within the previous one.
     * @minSize 2
     * @maxSize 10
     */
    nestedAggregations?: NestedAggregationItem[];
}
interface SearchDetails {
    /** Boolean search mode. Defines how separate search terms in the `expression` are combined. */
    mode?: ModeWithLiterals;
    /**
     * Search term or expression.
     * @maxLength 100
     */
    expression?: string | null;
    /**
     * Fields to search in.
     *
     * Searchable fields are `reservee.firstName`, `reservee.lastName`, `reservee.phone`, and `reservee.email`.
     *
     * If the array is empty, all fields are searched.
     * @maxSize 100
     * @maxLength 1000
     */
    fields?: string[];
    /**
     * Whether to allow the search function to automatically correct typos or minor mistakes in the search expression.
     * The search function uses an algorithm to find results that are close to what the site visitor typed.
     */
    fuzzy?: boolean;
}
declare enum Mode {
    /** Returns instances where any terms in the expression occur. */
    OR = "OR",
    /** Returns instances where all the terms in the expression occur. */
    AND = "AND"
}
/** @enumType */
type ModeWithLiterals = Mode | 'OR' | 'AND';
interface SearchReservationsResponse {
    /** List of Reservations. */
    reservations?: Reservation[];
    /** Cursor paging metadata. */
    pagingMetadata?: CursorPagingMetadata;
    /** Aggregation data. */
    aggregationData?: AggregationData;
}
interface AggregationData {
    /**
     * List of the aggregated data results.
     * @maxSize 1000
     */
    results?: AggregationResults[];
}
interface ValueAggregationResult {
    /**
     * Value of the field
     * @maxLength 1000
     */
    value?: string;
    /** Count of entities with this value */
    count?: number;
}
interface RangeAggregationResult {
    /** Inclusive lower bound of the range. */
    from?: number | null;
    /** Exclusive upper bound of the range. */
    to?: number | null;
    /** Count of entities in the range. */
    count?: number;
}
interface NestedAggregationResults extends NestedAggregationResultsResultOneOf {
    /** List of the value aggregation results. */
    values?: ValueResults;
    /** List of the range aggregation results. */
    ranges?: RangeResults;
    /** List of the scalar aggregation results. */
    scalar?: AggregationResultsScalarResult;
    /**
     * Aggregation name defined in the request.
     * @maxLength 1000
     */
    name?: string;
    /** Type of aggregation performed. */
    type?: AggregationTypeWithLiterals;
    /**
     * Field the data was aggregated by.
     * @maxLength 1000
     */
    fieldPath?: string;
}
/** @oneof */
interface NestedAggregationResultsResultOneOf {
    /** List of the value aggregation results. */
    values?: ValueResults;
    /** List of the range aggregation results. */
    ranges?: RangeResults;
    /** List of the scalar aggregation results. */
    scalar?: AggregationResultsScalarResult;
}
interface ValueResults {
    /**
     * List of value aggregations.
     * @maxSize 1000
     */
    results?: ValueAggregationResult[];
}
interface RangeResults {
    /**
     * List of ranges returned in same order as requested.
     * @maxSize 1000
     */
    results?: RangeAggregationResult[];
}
interface AggregationResultsScalarResult {
    /** Type of scalar aggregation. */
    type?: ScalarTypeWithLiterals;
    /** Value of the scalar aggregation. */
    value?: number;
}
interface NestedValueAggregationResult {
    /** @maxLength 1000 */
    value?: string;
    nestedResults?: NestedAggregationResults;
}
interface ValueResult {
    /**
     * Value of the field.
     * @maxLength 1000
     */
    value?: string;
    /** Count of entities with this value. */
    count?: number | null;
}
interface RangeResult {
    /** Inclusive lower bound of the range. */
    from?: number | null;
    /** Exclusive upper bound of the range. */
    to?: number | null;
    /** Count of entities in the range. */
    count?: number | null;
}
interface ScalarResult {
    /** Scalar aggregation results. */
    value?: number;
}
interface NestedResultValue extends NestedResultValueResultOneOf {
    /** Value aggregation results. */
    value?: ValueResult;
    /** Range aggregation results. */
    range?: RangeResult;
    /** Scalar aggregation results. */
    scalar?: ScalarResult;
    /** Date histogram aggregation results. */
    dateHistogram?: ValueResult;
}
/** @oneof */
interface NestedResultValueResultOneOf {
    /** Value aggregation results. */
    value?: ValueResult;
    /** Range aggregation results. */
    range?: RangeResult;
    /** Scalar aggregation results. */
    scalar?: ScalarResult;
    /** Date histogram aggregation results. */
    dateHistogram?: ValueResult;
}
interface Results {
    /** List of nested aggregation results. */
    results?: Record<string, NestedResultValue>;
}
interface DateHistogramResult {
    /**
     * Date in ISO 8601 format.
     * @maxLength 100
     */
    value?: string;
    /** Count of entities in the interval. */
    count?: number;
}
/** deprecated */
interface GroupByValueResults {
    /** @maxSize 1000 */
    results?: NestedValueAggregationResult[];
}
interface DateHistogramResults {
    /**
     * List of date histogram aggregations.
     * @maxSize 200
     */
    results?: DateHistogramResult[];
}
/**
 * Results of `NESTED` aggregation type in a flattened form.
 * Aggregations in the resulting array are keyed by the requested aggregation `name`.
 */
interface NestedResults {
    /**
     * List of nested aggregation results.
     * @maxSize 1000
     */
    results?: Results[];
}
interface AggregationResults extends AggregationResultsResultOneOf {
    /** Value aggregation results. */
    values?: ValueResults;
    /** Range aggregation results. */
    ranges?: RangeResults;
    /** Scalar aggregation results. */
    scalar?: AggregationResultsScalarResult;
    /** deprecated */
    groupedByValue?: GroupByValueResults;
    /** Date histogram aggregation results. */
    dateHistogram?: DateHistogramResults;
    /** Nested aggregation results. */
    nested?: NestedResults;
    /**
     * Aggregation name defined in the request.
     * @maxLength 1000
     */
    name?: string;
    /** Type of aggregation that was performed. */
    type?: AggregationTypeWithLiterals;
    /**
     * Field the data was aggregated by.
     * @maxLength 1000
     */
    fieldPath?: string;
}
/** @oneof */
interface AggregationResultsResultOneOf {
    /** Value aggregation results. */
    values?: ValueResults;
    /** Range aggregation results. */
    ranges?: RangeResults;
    /** Scalar aggregation results. */
    scalar?: AggregationResultsScalarResult;
    /** deprecated */
    groupedByValue?: GroupByValueResults;
    /** Date histogram aggregation results. */
    dateHistogram?: DateHistogramResults;
    /** Nested aggregation results. */
    nested?: NestedResults;
}
interface BulkArchiveReservationsRequest {
    /**
     * Reservation IDs to archive.
     * @minSize 1
     * @maxSize 100
     * @format GUID
     */
    reservationIds: string[];
}
interface BulkArchiveReservationsResponse {
    /**
     * Bulk archive action results.
     * @minSize 1
     * @maxSize 100
     */
    results?: BulkArchiveReservationsResult[];
    /** Bulk action metadata. */
    bulkActionMetadata?: BulkActionMetadata;
}
interface BulkArchiveReservationsResult {
    /** Item metadata. */
    itemMetadata?: ItemMetadata;
}
interface ItemMetadata {
    /**
     * Item ID. Should always be available, unless it's impossible (for example, when failing to create an item).
     * @format GUID
     */
    id?: string | null;
    /** Index of the item within the request array. Allows for correlation between request and response items. */
    originalIndex?: number;
    /** Whether the requested action was successful for this item. When `false`, the `error` field is populated. */
    success?: boolean;
    /** Details about the error in case of failure. */
    error?: ApplicationError;
}
interface ApplicationError {
    /** Error code. */
    code?: string;
    /** Description of the error. */
    description?: string;
    /** Data related to the error. */
    data?: Record<string, any> | null;
}
interface BulkActionMetadata {
    /** Number of items that were successfully processed. */
    totalSuccesses?: number;
    /** Number of items that couldn't be processed. */
    totalFailures?: number;
    /** Number of failures without details because detailed failure threshold was exceeded. */
    undetailedFailures?: number;
}
interface BulkUnArchiveReservationsRequest {
    /**
     * Reservation IDs to unarchive.
     * @minSize 1
     * @maxSize 100
     * @format GUID
     */
    reservationIds: string[];
}
interface BulkUnArchiveReservationsResponse {
    /**
     * Bulk unarchive action results.
     * @minSize 1
     * @maxSize 100
     */
    results?: BulkUnArchiveReservationsResult[];
    /** Bulk action metadata. */
    bulkActionMetadata?: BulkActionMetadata;
}
interface BulkUnArchiveReservationsResult {
    /** Item metadata. */
    itemMetadata?: ItemMetadata;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function createReservation(): __PublicMethodMetaInfo<'POST', {}, CreateReservationRequest$1, CreateReservationRequest, CreateReservationResponse$1, CreateReservationResponse>;
declare function getReservation(): __PublicMethodMetaInfo<'GET', {
    reservationId: string;
}, GetReservationRequest$1, GetReservationRequest, GetReservationResponse$1, GetReservationResponse>;
declare function updateReservation(): __PublicMethodMetaInfo<'PATCH', {
    reservationId: string;
}, UpdateReservationRequest$1, UpdateReservationRequest, UpdateReservationResponse$1, UpdateReservationResponse>;
declare function createHeldReservation(): __PublicMethodMetaInfo<'POST', {}, CreateHeldReservationRequest$1, CreateHeldReservationRequest, CreateHeldReservationResponse$1, CreateHeldReservationResponse>;
declare function reserveReservation(): __PublicMethodMetaInfo<'POST', {
    reservationId: string;
}, ReserveReservationRequest$1, ReserveReservationRequest, ReserveReservationResponse$1, ReserveReservationResponse>;
declare function cancelReservation(): __PublicMethodMetaInfo<'POST', {
    reservationId: string;
}, CancelReservationRequest$1, CancelReservationRequest, CancelReservationResponse$1, CancelReservationResponse>;
declare function deleteReservation(): __PublicMethodMetaInfo<'DELETE', {
    reservationId: string;
}, DeleteReservationRequest$1, DeleteReservationRequest, DeleteReservationResponse$1, DeleteReservationResponse>;
declare function listReservations(): __PublicMethodMetaInfo<'GET', {}, ListReservationsRequest$1, ListReservationsRequest, ListReservationsResponse$1, ListReservationsResponse>;
declare function queryReservations(): __PublicMethodMetaInfo<'POST', {}, QueryReservationsRequest$1, QueryReservationsRequest, QueryReservationsResponse$1, QueryReservationsResponse>;
declare function searchReservations(): __PublicMethodMetaInfo<'POST', {}, SearchReservationsRequest$1, SearchReservationsRequest, SearchReservationsResponse$1, SearchReservationsResponse>;
declare function bulkArchiveReservations(): __PublicMethodMetaInfo<'POST', {}, BulkArchiveReservationsRequest$1, BulkArchiveReservationsRequest, BulkArchiveReservationsResponse$1, BulkArchiveReservationsResponse>;
declare function bulkUnArchiveReservations(): __PublicMethodMetaInfo<'POST', {}, BulkUnArchiveReservationsRequest$1, BulkUnArchiveReservationsRequest, BulkUnArchiveReservationsResponse$1, BulkUnArchiveReservationsResponse>;

export { type __PublicMethodMetaInfo, bulkArchiveReservations, bulkUnArchiveReservations, cancelReservation, createHeldReservation, createReservation, deleteReservation, getReservation, listReservations, queryReservations, reserveReservation, searchReservations, updateReservation };
